// Popis: Rozsireny filtr
// Autor: VasaM
// Licence: CC BY 4.0 CZ

const cacheTypeCount = 14;
const waypointTypeCount = 6;
var hideTypes = [];
var filterTypes = [
	'traditional',
	'multi',
	'unknown',
	'letterbox',
	'wherigo',
	'virtual',
	'earth',
	'webcam',
	'lab',
	'event',
	'cito',
	'mega',
	'giga',
	'gps',
	'wp_final',
	'wp_stage',
	'wp_question',
	'wp_parking',
	'wp_trailhead',
	'wp_reference',
]
var filterTypesNames = [
	'Traditional Cache',
	'Multi-cache',
	'Unknown Cache',
	'Letterbox Hybrid',
	'Wherigo Cache',
	'Virtual Cache',
	'Earthcache',
	'Webcam Cache',
	'Lab Cache',
	'Event Cache',
	'Cache In Trash Out Event',
	'Mega-Event Cache',
	'Giga-Event Cache',
	'GPS Adventures Exhibit',
	'Final Location',
	'Stages of a Multicache',
	'Question to Answer',
	'Parking Area',
	'Trailhead',
	'Reference Point',
]



// Vytvori filtraci podle ikon
function addIconFilter() {
	function prepareIcon(id, name) {
		var icon = '';
		icon += '<div class="type-filter" id="' + id + '" data-type="' + name + '" title="' + name + '">';
		icon += '   <img class="type-filter-icon" src="plugin/ExtendedFilters/' + id + '.gif">';
		icon += '</div>';
		
		return icon;
	}

	var panel = '<div id="type-filter-panel" class="leaflet-control-layers panel">';
	panel    += '<h3 id="Caches-header">Caches</h3>';

	for (var i = 0; i < cacheTypeCount; ++i) {
		var id = filterTypes[i];
		var name = filterTypesNames[i];

		panel += prepareIcon(id, name);
	}

	panel += '<div class="type-filter"></div>';
	panel += '<h3 id="Waypoints-header">Waypoints</h3>';

	for (var i = cacheTypeCount; i < cacheTypeCount + waypointTypeCount; ++i) {
		var id = filterTypes[i];
		var name = filterTypesNames[i];

		panel += prepareIcon(id, name);
	}

	panel += '<input type="button" name="showAll" id="showAll" value="Show">';
	panel += '<input type="button" name="hideAll" id="hideAll" value="Hide">';
	panel += '<input type="button" name="invert" id="invert" value="Invert">';
	panel += '</div>';

	$('#filter-panel').after(panel);



	// Obsluha kliknuti na tlacitko
	function filterClicked(e) {
		var type = $(e).data('type');

		// Povolim zobrazeni
		if ($(e).hasClass('hide')) {
			hideTypes.splice( $.inArray(type, hideTypes), 1 );
			$(e).removeClass('hide');
		}
		// Zakazu zobrazeni
		else {
			if ($.inArray(type, hideTypes) == -1) {
				hideTypes.push(type);
			}
			$(e).addClass('hide');
		}
	}

	// Zaregistruji obsluhu filtru
	$.each(filterTypes, function() {
		$("#" + this).click(function() {
			filterClicked(this);
			load_ajax();
		});
	});

	// Obsluha tlacitka showAll
	$("#showAll").click(function() {
		$.each(filterTypes, function() {
			$("#" + this).addClass('hide');
			filterClicked($("#" + this));
		});
		load_ajax();
	});

	// Obsluha tlacitka hideAll
	$("#hideAll").click(function() {
		$.each(filterTypes, function() {
			$("#" + this).removeClass('hide');
			filterClicked($("#" + this));
		});
		load_ajax();
	});

	// Obsluha tlacitka invert
	$("#invert").click(function() {
		$.each(filterTypes, function() {
			filterClicked($("#" + this));
		});
		load_ajax();
	});

	// Obsluha napisu Caches
	$('#Caches-header').click(function() {
		for (var i = 0; i < cacheTypeCount; ++i) {
			filterClicked($('#' + filterTypes[i]));
		}
		load_ajax();
	});

	// Obsluha napisu Waypoints
	$('#Waypoints-header').click(function() {
		for (var i = cacheTypeCount; i < cacheTypeCount + waypointTypeCount; ++i) {
			filterClicked($('#' + filterTypes[i]));
		}
		load_ajax();
	});
}



function addAdvanced() {
	var advanced = '';
	advanced += '<div id="advanced" class="noprint leaflet-control-layers panel">';

	advanced += '<input type="checkbox" id="hideSolved" name="hideSolved" checked onchange="load_ajax()">';
	advanced += '<label for="hideSolved"> Solved</label><br>';
	
	advanced += '<input type="checkbox" id="hideVisited" name="hideVisited" checked onchange="load_ajax()">';
	advanced += '<label for="hideVisited"> Visited</label>';
	
	advanced += '</div>';

	$('#filter-panel').after(advanced);
}



// True pokud se ma ikona kese skryt
function filterCache() {
	var item = arguments[0][1];

	// Skryji kese podle typu
	if ($.inArray(item.t, hideTypes) != -1) {
		return true;
	}

	// Skryji vychozi ikony vylustenych kesi
	if (! $("#hideSolved").prop("checked") && item.fi == 1) {
		return true;
	}

	return false;
}


// True pokud se ma ikona waypointu skryt
function filterWaypoint() {
	var item = arguments[0][1];
	
	// Skryji waypointy podle typu
	if ($.inArray(item.t, hideTypes) != -1) {
		return true;
	}

	// Skryji navstivene waypointy
	if (! $("#hideVisited").prop("checked") && (item.f & 4) > 0) {
		return true;
	}

	return false;
}


function ExtendedFilters_ggm_init() {
	loadcss('plugin/ExtendedFilters.css');
	
	ggmregister('onload', function() {
		addIconFilter();
		addAdvanced();
	});

	ggmregister('filterpoint', filterCache);
	ggmregister('filterwpt', filterWaypoint);

	ggmregister('loadbbox', function() {
		if (groupCache._latlngMarkers.total) {
        	document.getElementById("point_count").innerHTML=(groupCache._latlngMarkers.total);
		}
	});
}
